<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Control.inc.php                                                05/12/2004
 * This script will read the control.dat file and place its information into
 * an array for global use.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2004 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('include_dir.php');                    // Get include directory.
require_once($includeDir . 'va-functions.inc.php'); // A VADV-PHP script.
require_once($includeDir . 'va-main.inc.php');      // Include BBS main configuration.


/**
* Va-Control.inc.php :: GetControl()
*
* This function will retrive the node information that is stored in the
* control.dat file.
*
* @param [type] $node
* @return
*/
function GetControl($node) {
    if ((!is_int($node)) && (!is_string($node))) {
        trigger_error(VA_Error(1));
    }
    $node = intval($node);

    global $VA_MAIN;                        // Include global variable.
    global $VA_SYSPATHS;                    // Include global variable.
    
    if ($node < 0) {
        $node = 0;
    }
    if ($node > $VA_MAIN['maxchannelno']) {
        return FALSE;
    }

    $fileString = ReadControl();
    if ($fileString === FALSE) {
        trigger_error(VA_Error(3));
    }

    $control = array();
    $offset  = 106 * $node;
    $control['baudrate']   = GetLongInt($fileString, 1 + $offset);
    $control['action']     = GetString($fileString, 5 + $offset, 24);
    $control['userno']     = GetLongInt($fileString, 29 + $offset);
    $control['handle']     = GetString($fileString, 33 + $offset, 32);
    $control['logintime']  = GetLongInt($fileString, 65 + $offset);
    $control['houron']     = GetInteger($fileString, 69 + $offset);
    $control['minuteon']   = GetInteger($fileString, 71 + $offset);
    $control['teleconflg'] = GetInteger($fileString, 73 + $offset);
    $control['currscript'] = GetString($fileString, 75 + $offset, 8);
    $control['logindate']  = GetString($fileString, 83 + $offset, 6);
    $control['blackflag']  = GetInteger($fileString, 89 + $offset);
    $control['filebits']   = GetInteger($fileString, 91 + $offset);
    $control['timeadjust'] = GetInteger($fileString, 93 + $offset);
    $control['extra']      = GetString($fileString, 95 + $offset, 8);
    $control['unknown']    = GetLongInt($fileString, 103 + $offset);

    // Setup default extended values available with VADV32.
    $control['socket']     = '';
    $control['ip']         = '';
    $control['hostname']   = '';
    // Check to see if VADV32 extended values exist and if so assign the variables.
    $va32node = $VA_SYSPATHS['temp'] . '\n' . $node . '\tcpip.cfg';
    if (is_file($va32node)) {
        $va32info = file ($va32node);       // Read the file.
        $control['socket']   = $va32info[0];
        $control['ip']       = $va32info[1];
        $control['hostname'] = $va32info[2];
    }
    
    return $control;
}


/**
* Va-Control.inc.php :: PutControl()
*
* This function will write updated information to the control.dat file, which
* is used to determine the current users online.
*
* @param [type] $fileString
* @param [type] $node
* @param [type] $configVariable
* @return
*/
function PutControl($fileString, $node, $configVariable) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }
    if ((!is_int($node)) && (!is_string($node))) {
            trigger_error(VA_Error(1));
    }
    if (!is_array($configVariable)) {
        trigger_error(VA_Error(1));
    }
    $node = intval($node);

    $total = intval(strlen($fileString) / 106);
    if ($node > $total) {
        $fileString = $fileString . str_pad('', 106, chr(0));
    }

    $offset = 106 * ($node - 1);
    if (isset($configVariable['baudrate']))   $fileString = PutLongInt($fileString, $configVariable['baudrate'], 1 + $offset);
    if (isset($configVariable['action']))     $fileString = PutString($fileString, $configVariable['action'], 5 + $offset, 24);
    if (isset($configVariable['userno']))     $fileString = PutLongInt($fileString, $configVariable['userno'], 29 + $offset);
    if (isset($configVariable['handle']))     $fileString = PutString($fileString, $configVariable['handle'], 33 + $offset, 32);
    if (isset($configVariable['logintime']))  $fileString = PutLongInt($fileString, $configVariable['logintime'], 65 + $offset);
    if (isset($configVariable['houron']))     $fileString = PutInteger($fileString, $configVariable['houron'], 69 + $offset);
    if (isset($configVariable['minuteon']))   $fileString = PutInteger($fileString, $configVariable['minuteon'], 71 + $offset);
    if (isset($configVariable['teleconflg'])) $fileString = PutInteger($fileString, $configVariable['teleconflg'], 73 + $offset);
    if (isset($configVariable['currscript'])) $fileString = PutString($fileString, $configVariable['currscript'], 75 + $offset, 8);
    if (isset($configVariable['logindate']))  $fileString = PutString($fileString, $configVariable['logindate'], 83 + $offset, 6);
    if (isset($configVariable['blackflag']))  $fileString = PutInteger($fileString, $configVariable['blackflag'], 89 + $offset);
    if (isset($configVariable['filebits']))   $fileString = PutInteger($fileString, $configVariable['filebits'], 91 + $offset);
    if (isset($configVariable['timeadjust'])) $fileString = PutInteger($fileString, $configVariable['timeadjust'], 93 + $offset);
    if (isset($configVariable['extra']))      $fileString = PutString($fileString, $configVariable['extra'], 95 + $offset, 12);
    
    return $fileString;                     // Return the new file string.
}


/**
* Va-Control.inc.php :: ReadControl()
*
* This function will read the control.dat file.
*
* @return
*/
function ReadControl() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['control'] . '/control.dat';
    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Control.inc.php :: WriteControl()
*
* This function will write a new control.dat file based on the file string
* passed to it. If the file string is not in the correct format, then your
* control.dat file will become corrupt and the BBS could stop functioning!
*
* @param [type] $fileString
* @return
*/
function WriteControl($fileString) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['control'] . '/control.dat';
    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}

?>
