<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Vote.inc.php                                                   05/12/2004
 * This script will retrieve all of the informaton related to the configured
 * voting informatoin that are found in VOTE.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2004 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('include_dir.php');                    // Get include directory.
require_once($includeDir . 'va-functions.inc.php'); // A VADV-PHP script.


/**
* Va-Vote.inc.php :: GetVote()
*
* Retrieve all of the voting information and store it into a multidimensional
* array.
*
* Array format: $vote[1]['setting']
*               $vote[0] = Total number of questions.
*
* @return
*/
function GetVote() {
    $fileString = ReadVote();
    if ($fileString === FALSE) {
        trigger_error(VA_Error(3));
    }

    $vote   = array();                      // Create the array.
    $offset = 0;

    for ($x = 1; $offset < strlen($fileString); $x++) {
        $vote[$x]['question'] = GetString($fileString, 1 + $offset, 64);
        $vote[$x]['respno']   = GetInteger($fileString, 65 + $offset);
        $vote[$x]['resp1']    = GetString($fileString, 67 + $offset, 60);
        $vote[$x]['resp2']    = GetString($fileString, 127 + $offset, 60);
        $vote[$x]['resp3']    = GetString($fileString, 187 + $offset, 60);
        $vote[$x]['resp4']    = GetString($fileString, 247 + $offset, 60);
        $vote[$x]['resp5']    = GetString($fileString, 307 + $offset, 60);
        $vote[$x]['resp6']    = GetString($fileString, 367 + $offset, 60);
        $vote[$x]['resp7']    = GetString($fileString, 427 + $offset, 60);
        $vote[$x]['resp8']    = GetString($fileString, 487 + $offset, 60);
        $offset = 547 * $x;
    }

    $vote[0] = $x - 1;                      // Put the number of voting questions in position 0.

    return $vote;                           // Return the voting information.

}


/**
* Va-Vote.inc.php :: PutVote()
*
* This function will change the vote.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
* @param [type] $fileString
* @param [type] $configVariable
* @return
*/
function PutUpload($fileString, $configVariable) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }
    if (!is_array($configVariable)) {
        trigger_error(VA_Error(1));
    }

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.
    $offset  = 0;

    for ($x = 1; $pointer < $length; $x++) {
        $total = intval(strlen($fileString) / 547);
        if ($x > $total) {
            $fileString = $fileString . str_pad('', 547, chr(0));
        }

        if (isset($configVariable[$x])) {
            $pointer++;
            if (isset($configVariable[$x]['question'])) $fileString = PutString($fileString, $configVariable[$x]['question'], 1 + $offset, 64);
            if (isset($configVariable[$x]['respno']))   $fileString = PutInteger($fileString, $configVariable[$x]['respno'], 65 + $offset);
            if (isset($configVariable[$x]['resp1']))    $fileString = PutString($fileString, $configVariable[$x]['resp1'], 67 + $offset, 60);
            if (isset($configVariable[$x]['resp2']))    $fileString = PutString($fileString, $configVariable[$x]['resp2'], 127 + $offset, 60);
            if (isset($configVariable[$x]['resp3']))    $fileString = PutString($fileString, $configVariable[$x]['resp3'], 187 + $offset, 60);
            if (isset($configVariable[$x]['resp4']))    $fileString = PutString($fileString, $configVariable[$x]['resp4'], 247 + $offset, 60);
            if (isset($configVariable[$x]['resp5']))    $fileString = PutString($fileString, $configVariable[$x]['resp5'], 307 + $offset, 60);
            if (isset($configVariable[$x]['resp6']))    $fileString = PutString($fileString, $configVariable[$x]['resp6'], 367 + $offset, 60);
            if (isset($configVariable[$x]['resp7']))    $fileString = PutString($fileString, $configVariable[$x]['resp7'], 427 + $offset, 60);
            if (isset($configVariable[$x]['resp8']))    $fileString = PutString($fileString, $configVariable[$x]['resp8'], 487 + $offset, 60);
        }
        $offset = 547 * $x;
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Vote.inc.php :: ReadVote()
*
* This function will read the vote.cfg file.
*
* @return
*/
function ReadVote() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/vote.cfg';
    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Vote.inc.php :: WriteVote()
*
* This function will write a new vote.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* vote.cfg file will become corrupt and the BBS could stop functioning!
*
* @param [type] $fileString
* @return
*/
function WriteVote($fileString) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/vote.cfg';
    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the voting information automatically.
$VA_VOTE = GetVote();

?>
