<?php
/*
 * ----------------------------------------------------------------------------
 * VADV-PHP_Dat.inc.php                                              05/12/2004
 * This script will read the vadv-php.dat file for the specified user and store
 * its information into an array. This data file is not created by VADV, but is
 * a VADV-PHP settings file that stores various user preferences.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2004 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('include_dir.php');                    // Get include directory.
require_once($includeDir . 'va-functions.inc.php'); // A VADV-PHP script.


/**
* VADV-PHP_Dat.inc.php :: GetUserSettings()
*
* This function will get the requested entry information from vadv-php.dat.
*
* @param [type] $userNo
* @return
*/
function GetUserSettings($userNo) {
    if ((!is_int($userNo)) && (!is_string($userNo))) {
        trigger_error(VA_Error(1));
    }
    $userNo = intval($userNo);
    if ($userNo <= 0) {
        return 0;
    }

    $fileString = ReadUserSettings();

    $user   = array();
    $offset = 100 * ($userNo - 1);
    $user['hidedeleted'] = GetInteger($fileString, 1 + $offset);
    
    // If any of the settings are not present, then set them to the defaults.
    if ($user['hidedeleted'] == '') {
        $user['hidedeleted'] = 0;
    }

    return $user;                           // Return the user information.
}


/**
* Va-Userfile.inc.php :: PutUserSettings()
*
* This function will put new information into the vadv-php.dat file string.
*
* @param [type] $fileString
* @param [type] $userNo
* @param [type] $configVariable
* @return
*/
function PutUserSettings($fileString, $userNo, $configVariable) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }
    if ((!is_int($userNo)) && (!is_string($userNo))) {
        trigger_error(VA_Error(1));
    }
    if (!is_array($configVariable)) {
        trigger_error(VA_Error(1));
    }
    $userNo = intval($userNo);

    $total = intval(strlen($fileString) / 82);
    if ($userNo > $total) {
        $fileString = $fileString . str_pad('', 82, chr(0));
    }

    $offset = 100 * ($userNo - 1);
    if (isset($configVariable['hidedeleted'])) $fileString = PutInteger($fileString, $configVariable['hidedeleted'], 1 + $offset);

    return $fileString;                     // Return the new file string.
}


/**
* VADV-PHP_Dat.inc.php :: ReadUserSettings()
*
* This function will read the vadv-php.dat file.
*
* @return
*/
function ReadUserSettings() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['data'] . '/vadv-php.dat';
    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* VADV-PHP_Dat.inc.php :: WriteUserSettings()
*
* This function writes the new file string into vadv-php.dat.
*
* @param [type] $fileString
* @return
*/
function WriteUserSettings($fileString) {
    if (!is_string($fileString)) {
        trigger_error(VA_Error(1));
    }

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['data'] . '/vadv-php.dat';
    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}
?>
